# Gitea Workflow

A Visual Studio Code extension that allows you to clone repositories from your Gitea instance via SSH, manage Gitea authentication using a Personal Access Token (PAT), and create Pull Requests (PRs) directly from your workspace.

## Features

- **Gitea Authentication**: Authenticate with your Gitea instance using a Personal Access Token.
- **Clone via SSH**: Clone repositories from Gitea using SSH URLs.
- **Auto-Open Repository**: After cloning, the repository will be automatically opened in the workspace.
- **See Open Pull Requests**: Use the icon in the status bar or the command to check how many open PRs exist and open them in a browser.  
- **Create Pull Requests**: Create Pull Requests (PRs) directly from your workspace

## Commands

- `Gitea: Authenticate`: Authenticate with your Gitea instance using your Personal Access Token (PAT).
- `Gitea: Configure`: Set the URL of your Gitea instance and your PAT.
- `Gitea: Clone Repository`: Clone a repository from Gitea via SSH.
- `Gitea: Create Pull Request`: Create a pull request for the current repository.
- `Gitea: Show Open Pull Request`: Shows open pull request for the current repository and link to them.

## Requirements

    A Gitea instance with SSH access.
    A Personal Access Token (PAT) from your Gitea instance for authentication.

## Configuration
You can configure the Gitea instance URL, your Personal Access Token, and default clone settings in your VSCode settings:

```json
{
  "gitea.instanceUrl": "https://your-gitea-instance.com",
  "gitea.personalAccessToken": "your-personal-access-token",
}
````

## Usage

### Authentication

Run `Gitea: Authenticate` to authenticate with your Gitea instance.  
You can set or update your Gitea instance URL and Personal Access Token by running `Gitea: Configure`

### Cloning a Repository

Run `Gitea: Clone Repository` to clone a repository from your Gitea account.  
Choose the repository you want to clone and select the folder where you want to clone it.  
The repository will be cloned via SSH and automatically opened in VSCode.

### Creating a Pull Request

_Ensure that you are on the branch for which you want to create a Pull Request._  
Run `Gitea: Create Pull Request` from the command palette.  
The PR title will be automatically set to the latest commit message, and the body will include the commit description (if any).  
The current branch will be used as the source (head), and the base branch will be automatically fetched from the repository's default branch (e.g., main or master).  
Once the Pull Request is created, the Gitea web interface will open in your browser for further review.  

## Issues

If you encounter any issues or have feature requests, please feel free to submit them in [the issues section](https://gitea.computerliebe.org/ComputerLiebe/Gitea-Workflow/issues).

